@@ -26,6 +26,7 @@ from lilya.compat import is_async_callable
 from lilya.concurrency import run_in_threadpool
 from lilya.conf import _monkay
 from lilya.conf.global_settings import Settings
+from lilya.contrib.documentation import Doc
 from lilya.datastructures import URL, Header, ScopeHandler, SendReceiveSniffer, URLPath
 from lilya.dependencies import wrap_dependency
 from lilya.enums import EventType, HTTPMethod, Match, ScopeType
@@ -38,7 +39,6 @@ from lilya.responses import PlainText, RedirectResponse, Response
 from lilya.types import (
     ASGIApp,
     Dependencies,
-    Doc,
     ExceptionHandler,
     Lifespan,
     Receive,
@@ -1396,6 +1396,13 @@ class BaseRouter:
         try:
             app: Any = scope.get("app")
             await receive()
+
+            # If it's a bound method (needs invoking to get the actual callable, example? From settings)
+            if inspect.ismethod(self.lifespan_context):
+                self.lifespan_context = (
+                    self.lifespan_context()
+                )  # should return a (app)->AsyncContextManager callable
+
             async with self.lifespan_context(app) as state:
                 if state is not None:
                     if "state" not in scope:
