@@ -5,16 +5,6 @@ from typing import (
     TypeVar,
 )
 
-try:
-    from typing_extensions import Doc
-except ModuleNotFoundError:
-    # stub
-
-    class Doc:  # type: ignore[no-redef]
-        def __init__(self, documentation: str, /) -> None:
-            self.documentation = documentation
-
-
 ApplicationType = TypeVar("ApplicationType")
 
 Scope = MutableMapping[str, Any]
